From a9e9cb118c660644f08f5574a40408064dc80661 Mon Sep 17 00:00:00 2001
From: sawinglogz <3787776-sawinglogz@users.noreply.gitlab.com>
Date: Wed, 16 Feb 2022 16:45:26 -0500
Subject: [PATCH 01/14] Fix a null pointer crash when reading PRS1 compliance
files with multiple chunks.
This doesn't happen normally, but OSCAR shouldn't crash, even when
encountering cards with corrupted directories.
---
Htmldocs/release_notes.html | 9 ++++++++-
oscar/SleepLib/loader_plugins/prs1_loader.cpp | 6 +++---
2 files changed, 11 insertions(+), 4 deletions(-)
diff --git a/Htmldocs/release_notes.html b/Htmldocs/release_notes.html
index 35e007ba..df148ffb 100644
--- a/Htmldocs/release_notes.html
+++ b/Htmldocs/release_notes.html
@@ -11,6 +11,14 @@
This page in other languages:
http://www.apneaboard.com/wiki/index.php/OSCAR_Release_Notes
+ Changes and fixes in OSCAR v1.3.5-alpha.2
+
Portions of OSCAR are © 2019-2022 by
+ The OSCAR Team
+
+ - [fix] File Export Sessions now exports statistics session data properly.
+ - [fix] Fixed a rare crash on import when encountering corrupted Philips Respironics directories.
+
+
Changes and fixes in OSCAR v1.3.5-alpha.0
Portions of OSCAR are © 2019-2022 by
The OSCAR Team
@@ -20,7 +28,6 @@
DreamStation 2 Auto CPAP Advanced (520X110C, 520X150C)
- [fix] File Export Sessions now exports statistics session data properly.
[new] Test Mantis integration.
diff --git a/oscar/SleepLib/loader_plugins/prs1_loader.cpp b/oscar/SleepLib/loader_plugins/prs1_loader.cpp
index c51c53e1..e04d0149 100644
--- a/oscar/SleepLib/loader_plugins/prs1_loader.cpp
+++ b/oscar/SleepLib/loader_plugins/prs1_loader.cpp
@@ -1167,11 +1167,11 @@ void PRS1Loader::ScanFiles(const QStringList & paths, int sessionid_base)
switch (ext) {
case 0:
if (task->compliance) {
- if (chunksIdentical(chunk, task->summary)) {
+ if (chunksIdentical(chunk, task->compliance)) {
// Never seen identical compliance chunks, so keep logging this for now.
- qDebug() << chunkComparison(chunk, task->summary);
+ qDebug() << chunkComparison(chunk, task->compliance);
} else {
- qWarning() << chunkComparison(chunk, task->summary);
+ qWarning() << chunkComparison(chunk, task->compliance);
}
delete chunk;
continue; // (skipping to avoid duplicates)
From 350f046ed45becc957e2ae450b90dcf6058d8c72 Mon Sep 17 00:00:00 2001
From: sawinglogz <3787776-sawinglogz@users.noreply.gitlab.com>
Date: Wed, 16 Feb 2022 16:47:05 -0500
Subject: [PATCH 02/14] Bump VERSION since we're past the release of alpha.0.
---
oscar/VERSION | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/oscar/VERSION b/oscar/VERSION
index 438a7313..5c612c19 100644
--- a/oscar/VERSION
+++ b/oscar/VERSION
@@ -1,4 +1,4 @@
// Update the string below to set OSCAR's version and release status.
// See https://semver.org/spec/v2.0.0.html for details on format.
-#define VERSION "1.3.5-alpha.0"
+#define VERSION "1.3.5-alpha.2"
From 182bbfcb1e53d718f1d370335a7e11db57a9b12b Mon Sep 17 00:00:00 2001
From: sawinglogz <3787776-sawinglogz@users.noreply.gitlab.com>
Date: Wed, 16 Feb 2022 19:04:17 -0500
Subject: [PATCH 03/14] Add 521X120C to the list of tested machines.
---
Htmldocs/release_notes.html | 5 +++++
oscar/SleepLib/loader_plugins/prs1_loader.cpp | 1 +
2 files changed, 6 insertions(+)
diff --git a/Htmldocs/release_notes.html b/Htmldocs/release_notes.html
index df148ffb..a92781c6 100644
--- a/Htmldocs/release_notes.html
+++ b/Htmldocs/release_notes.html
@@ -15,6 +15,11 @@
Portions of OSCAR are © 2019-2022 by
The OSCAR Team
+ - [new] Additional Philips Respironics devices tested and fully supported:
+
+ - DreamStation 2 Auto CPAP Advanced with P-Flex (521X120C)
+
+
- [fix] File Export Sessions now exports statistics session data properly.
- [fix] Fixed a rare crash on import when encountering corrupted Philips Respironics directories.
diff --git a/oscar/SleepLib/loader_plugins/prs1_loader.cpp b/oscar/SleepLib/loader_plugins/prs1_loader.cpp
index e04d0149..5d806da1 100644
--- a/oscar/SleepLib/loader_plugins/prs1_loader.cpp
+++ b/oscar/SleepLib/loader_plugins/prs1_loader.cpp
@@ -133,6 +133,7 @@ static const PRS1TestedModel s_PRS1TestedModels[] = {
{ "520X110C", 0, 6, "DreamStation 2 Auto CPAP Advanced" }, // based on bottom label, boot screen says "Advanced Auto CPAP"
{ "520X150C", 0, 6, "DreamStation 2 Auto CPAP Advanced" }, // from user report
+ { "521X120C", 0, 6, "DreamStation 2 Auto CPAP Advanced with P-Flex" }, // inferred from 501X120 and presence of "P-Flex" on bottom label
{ "950P", 5, 0, "BiPAP AutoSV Advanced System One" },
{ "951P", 5, 0, "BiPAP AutoSV Advanced System One" },
From df17e279f4c66802becd81e03d16fb30216798ae Mon Sep 17 00:00:00 2001
From: sawinglogz <3787776-sawinglogz@users.noreply.gitlab.com>
Date: Wed, 16 Feb 2022 20:50:47 -0500
Subject: [PATCH 04/14] Update F0V6 warnings based on new DS2 test data.
---
oscar/SleepLib/loader_plugins/prs1_parser_xpap.cpp | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/oscar/SleepLib/loader_plugins/prs1_parser_xpap.cpp b/oscar/SleepLib/loader_plugins/prs1_parser_xpap.cpp
index 56623419..f2d3fe6e 100644
--- a/oscar/SleepLib/loader_plugins/prs1_parser_xpap.cpp
+++ b/oscar/SleepLib/loader_plugins/prs1_parser_xpap.cpp
@@ -1557,7 +1557,7 @@ bool PRS1DataChunk::ParseSummaryF0V6(void)
qWarning() << this->sessionid << "summary data too short:" << chunk_size;
return false;
}
- if (chunk_size < 58) UNEXPECTED_VALUE(chunk_size, ">= 58");
+ if (chunk_size < 55) UNEXPECTED_VALUE(chunk_size, ">= 55");
bool ok = true;
int pos = 0;
From 3458b2b445d6e76887aa76f085857da6336e3af7 Mon Sep 17 00:00:00 2001
From: Phil Olynyk
Date: Thu, 17 Feb 2022 22:32:27 -0500
Subject: [PATCH 05/14] Make sure clean-rm doesn't delete the new files
---
Building/Linux/clean_rm-common-NN.old | 16 ++++++++++++++++
Building/Linux/clean_rm-common-NN.sh | 9 ++++++---
2 files changed, 22 insertions(+), 3 deletions(-)
create mode 100755 Building/Linux/clean_rm-common-NN.old
diff --git a/Building/Linux/clean_rm-common-NN.old b/Building/Linux/clean_rm-common-NN.old
new file mode 100755
index 00000000..7bde25e2
--- /dev/null
+++ b/Building/Linux/clean_rm-common-NN.old
@@ -0,0 +1,16 @@
+
+# begin common script shell
+# delete all the folder not deleted by the purge command
+
+echo "appli_name=${appli_name}"
+
+list=$(find /usr -name ${appli_name} 2>/dev/null)
+
+for folder in $list
+do
+ echo "to delete : '$folder'"
+ rm -r $folder
+done
+
+# end common script shell
+
diff --git a/Building/Linux/clean_rm-common-NN.sh b/Building/Linux/clean_rm-common-NN.sh
index 7bde25e2..f9413371 100755
--- a/Building/Linux/clean_rm-common-NN.sh
+++ b/Building/Linux/clean_rm-common-NN.sh
@@ -4,12 +4,15 @@
echo "appli_name=${appli_name}"
-list=$(find /usr -name ${appli_name} 2>/dev/null)
+list=$(find /usr/share -name ${appli_name} 2>/dev/null)
for folder in $list
do
- echo "to delete : '$folder'"
- rm -r $folder
+ if [ $folder != '/usr/share/OSCAR' ]
+ then
+ echo "to delete : '$folder'"
+ rm -r $folder
+ fi
done
# end common script shell
From acf04f4b459ae30728d7dd92857a7efd2695376c Mon Sep 17 00:00:00 2001
From: Phil Olynyk
Date: Fri, 18 Feb 2022 14:39:38 -0500
Subject: [PATCH 06/14] Move duplicate declarations of EDFType to edfparser and
combine them
---
oscar/SleepLib/loader_plugins/edfparser.h | 3 +++
oscar/SleepLib/loader_plugins/resmed_EDFinfo.h | 3 ++-
oscar/SleepLib/loader_plugins/sleepstyle_EDFinfo.h | 2 +-
3 files changed, 6 insertions(+), 2 deletions(-)
diff --git a/oscar/SleepLib/loader_plugins/edfparser.h b/oscar/SleepLib/loader_plugins/edfparser.h
index 7e90571b..2bb7778d 100644
--- a/oscar/SleepLib/loader_plugins/edfparser.h
+++ b/oscar/SleepLib/loader_plugins/edfparser.h
@@ -26,6 +26,9 @@ const char AnnoSep = 20;
const char AnnoDurMark = 21;
const char AnnoEnd = 0;
+// EDFType is used by all the edf loaders - resmed and sleepstyle, so far
+enum EDFType { EDF_UNKNOWN, EDF_BRP, EDF_PLD, EDF_SAD, EDF_EVE, EDF_CSL, EDF_AEV, EDF_RT };
+
/*! \struct EDFHeader
\brief Represents the EDF+ header structure, used as a place holder while processing the text data.
\note More information on the EDF+ file format can be obtained from http://edfplus.info
diff --git a/oscar/SleepLib/loader_plugins/resmed_EDFinfo.h b/oscar/SleepLib/loader_plugins/resmed_EDFinfo.h
index 2c4efb10..b8774b3e 100644
--- a/oscar/SleepLib/loader_plugins/resmed_EDFinfo.h
+++ b/oscar/SleepLib/loader_plugins/resmed_EDFinfo.h
@@ -16,7 +16,8 @@
#include "SleepLib/profiles.h"
#include "SleepLib/loader_plugins/edfparser.h"
-enum EDFType { EDF_UNKNOWN, EDF_BRP, EDF_PLD, EDF_SAD, EDF_EVE, EDF_CSL, EDF_AEV };
+// moved to edfparser.h
+// enum EDFType { EDF_UNKNOWN, EDF_BRP, EDF_PLD, EDF_SAD, EDF_EVE, EDF_CSL, EDF_AEV };
EDFType lookupEDFType(const QString & filename);
diff --git a/oscar/SleepLib/loader_plugins/sleepstyle_EDFinfo.h b/oscar/SleepLib/loader_plugins/sleepstyle_EDFinfo.h
index 32efd1db..180ac7cf 100644
--- a/oscar/SleepLib/loader_plugins/sleepstyle_EDFinfo.h
+++ b/oscar/SleepLib/loader_plugins/sleepstyle_EDFinfo.h
@@ -17,7 +17,7 @@
#include "SleepLib/loader_plugins/edfparser.h"
//enum EDFType { EDF_UNKNOWN, EDF_BRP, EDF_PLD, EDF_SAD, EDF_EVE, EDF_CSL, EDF_AEV };
-enum EDFType { EDF_UNKNOWN, EDF_RT };
+//enum EDFType { EDF_UNKNOWN, EDF_RT }; // moved to edfparser.h
// EDFType lookupEDFType(const QString & filename);
From a7e62666308bbf68f1d9511ce9d907651125bd53 Mon Sep 17 00:00:00 2001
From: sawinglogz <3787776-sawinglogz@users.noreply.gitlab.com>
Date: Sun, 20 Feb 2022 14:36:28 -0500
Subject: [PATCH 07/14] Bump version now that alpha.2 is in testing.
---
oscar/VERSION | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/oscar/VERSION b/oscar/VERSION
index 5c612c19..b1ea432a 100644
--- a/oscar/VERSION
+++ b/oscar/VERSION
@@ -1,4 +1,4 @@
// Update the string below to set OSCAR's version and release status.
// See https://semver.org/spec/v2.0.0.html for details on format.
-#define VERSION "1.3.5-alpha.2"
+#define VERSION "1.3.5-alpha.3"
From 3e069fa4de9303dea9b40b523cf94b15f89abd91 Mon Sep 17 00:00:00 2001
From: sawinglogz <3787776-sawinglogz@users.noreply.gitlab.com>
Date: Sun, 20 Feb 2022 14:37:05 -0500
Subject: [PATCH 08/14] Add 761P to the list of tested machines.
Also update F0V4 warnings based on new test data.
---
Htmldocs/release_notes.html | 11 +++++++++++
oscar/SleepLib/loader_plugins/prs1_loader.cpp | 1 +
oscar/SleepLib/loader_plugins/prs1_parser_xpap.cpp | 4 ++--
3 files changed, 14 insertions(+), 2 deletions(-)
diff --git a/Htmldocs/release_notes.html b/Htmldocs/release_notes.html
index a92781c6..4b196123 100644
--- a/Htmldocs/release_notes.html
+++ b/Htmldocs/release_notes.html
@@ -11,6 +11,17 @@
This page in other languages:
http://www.apneaboard.com/wiki/index.php/OSCAR_Release_Notes
+ Changes and fixes in OSCAR v1.3.5-alpha.X
+
Portions of OSCAR are © 2019-2022 by
+ The OSCAR Team
+
+ - [new] Additional Philips Respironics devices tested and fully supported:
+
+ - BiPAP Auto (System One 60 Series) (761P)
+
+
+
+
Changes and fixes in OSCAR v1.3.5-alpha.2
Portions of OSCAR are © 2019-2022 by
The OSCAR Team
diff --git a/oscar/SleepLib/loader_plugins/prs1_loader.cpp b/oscar/SleepLib/loader_plugins/prs1_loader.cpp
index 5d806da1..3e82b908 100644
--- a/oscar/SleepLib/loader_plugins/prs1_loader.cpp
+++ b/oscar/SleepLib/loader_plugins/prs1_loader.cpp
@@ -104,6 +104,7 @@ static const PRS1TestedModel s_PRS1TestedModels[] = {
{ "562P", 0, 4, "REMstar Auto (System One 60 Series)" },
{ "660P", 0, 4, "BiPAP Pro (System One 60 Series)" },
{ "760P", 0, 4, "BiPAP Auto (System One 60 Series)" },
+ { "761P", 0, 4, "BiPAP Auto (System One 60 Series)" },
{ "501V", 0, 5, "Dorma 500 Auto (System One 60 Series)" }, // (brick)
diff --git a/oscar/SleepLib/loader_plugins/prs1_parser_xpap.cpp b/oscar/SleepLib/loader_plugins/prs1_parser_xpap.cpp
index f2d3fe6e..8d5ac115 100644
--- a/oscar/SleepLib/loader_plugins/prs1_parser_xpap.cpp
+++ b/oscar/SleepLib/loader_plugins/prs1_parser_xpap.cpp
@@ -871,8 +871,8 @@ bool PRS1DataChunk::ParseSummaryF0V4(void)
CHECK_VALUE(data[pos+0xc], 0);
//CHECK_VALUE(data[pos+0xd], 0);
CHECK_VALUE(data[pos+0xe], 0);
- //CHECK_VALUE(data[pos+0xf], 0); // CA count, probably 16-bit
- CHECK_VALUE(data[pos+0x10], 0);
+ //CHECK_VALUE(data[pos+0xf], 0); // 16-bit CA count
+ //CHECK_VALUE(data[pos+0x10], 0);
//CHECK_VALUE(data[pos+0x11], 40); // 16-bit something: 0x88, 0x26, etc. ???
//CHECK_VALUE(data[pos+0x12], 0);
//CHECK_VALUE(data[pos+0x13], 0); // 16-bit minutes in LL
From 6b81db5bbbaaa5016884159adc9144a63d9d9472 Mon Sep 17 00:00:00 2001
From: LoudSnorer
Date: Tue, 22 Feb 2022 07:48:30 -0500
Subject: [PATCH 09/14] Problem *CSR pinned on overview tab disappears on the
first paint. Cause *Charts are automatically permanently disabled for charts
that are initially empty *This problem impacts any chart that is enabled in
File => Preferences. Details *gGraph does not display layers (paint) when the
layer is empty. *gSummaryChart (layer) initializes empty to false and
calculates empty during painting. Causing empty charts to be permanently
disabled. *Once a chart has been displayed, it will always be displayed even
if empty. Solution *Enabled painting charts when the DayRange is increased,
triggering the empty flag to be recalculated New non-empty charts will now be
permanently displayed *Overview maintains the largest DayRange used and list
of empty charts. *Overview receive these signals and calls recalculates when
largest DayRange is increased. *gSummaryChart implement recalculate method.
*gSummaryChart implement emit signal when empty flag changes. *gGraphView
implement emit signal when day range changes. (XBounds) **** IMPORTANT MUST
Rebuild makefiles.**** *Remove two Makefiles and execute qmake. (works for
linux version).
---
oscar/Graphs/gGraphView.cpp | 19 ++-
oscar/Graphs/gGraphView.h | 1 +
oscar/Graphs/gSessionTimesChart.cpp | 32 +++-
oscar/Graphs/gSessionTimesChart.h | 10 +-
oscar/overview.cpp | 242 +++++++++++++++++++++++-----
oscar/overview.h | 27 +++-
6 files changed, 272 insertions(+), 59 deletions(-)
diff --git a/oscar/Graphs/gGraphView.cpp b/oscar/Graphs/gGraphView.cpp
index 577c56bc..3e25a339 100644
--- a/oscar/Graphs/gGraphView.cpp
+++ b/oscar/Graphs/gGraphView.cpp
@@ -7,6 +7,20 @@
* License. See the file COPYING in the main directory of the source code
* for more details. */
+#define xDEBUG_FUNCTIONS
+#ifdef DEBUG_FUNCTIONS
+#include
+#define DEBUG qDebug()<
@@ -470,7 +484,7 @@ void gGraphView::popoutGraph()
qDebug() << "widget geometry" << newDockWidget->frameGeometry() << "title bar height" << titleBarHeight;
if (newDockHeight > screenHeight) {
QMessageBox::warning(nullptr, STR_MessageBox_Warning,
- QObject::tr("The popout window is full. You should capture the existing\npopout window, delete it, then pop out this graph again."));
+ QObject::tr("The popout window is full. You should capture the existing\npopout window, delete it, then pop out this graph again."));
return;
}
qDebug() << "dock height" << dock->height() << "popout graph height" << popout_graph->height();
@@ -1151,6 +1165,8 @@ void gGraphView::GetXBounds(qint64 &st, qint64 &et)
// Supplies time range to all graph objects in linked group, refreshing if requested
void gGraphView::SetXBounds(qint64 minx, qint64 maxx, short group, bool refresh)
{
+ bool changed= (minx!=m_minx)||(maxx!=m_maxx);
+
for (auto & graph : m_graphs) {
if ((graph->group() == group)) {
graph->SetXBounds(minx, maxx);
@@ -1161,6 +1177,7 @@ void gGraphView::SetXBounds(qint64 minx, qint64 maxx, short group, bool refresh)
m_maxx = maxx;
if (refresh) { timedRedraw(0); }
+ if (changed) emit XBoundsChanged(minx ,maxx);
}
void gGraphView::updateScrollBar()
diff --git a/oscar/Graphs/gGraphView.h b/oscar/Graphs/gGraphView.h
index 8b044a46..0dd6226e 100644
--- a/oscar/Graphs/gGraphView.h
+++ b/oscar/Graphs/gGraphView.h
@@ -707,6 +707,7 @@ class gGraphView
void updateCurrentTime(double);
void updateRange(double,double);
void GraphsChanged();
+ void XBoundsChanged(qint64 ,qint64);
public slots:
//! \brief Callback from the ScrollBar, to change scroll position
diff --git a/oscar/Graphs/gSessionTimesChart.cpp b/oscar/Graphs/gSessionTimesChart.cpp
index adcc1770..1f9ec008 100644
--- a/oscar/Graphs/gSessionTimesChart.cpp
+++ b/oscar/Graphs/gSessionTimesChart.cpp
@@ -7,6 +7,20 @@
* License. See the file COPYING in the main directory of the source code
* for more details. */
+#define xDEBUG_FUNCTIONS
+#ifdef DEBUG_FUNCTIONS
+#include
+#define DEBUG qDebug()<
#include
#include
@@ -104,13 +118,11 @@ void gSummaryChart::SetDay(Day *unused_day)
m_maxy = 20;
m_empty = false;
+ m_emptyPrev = true;
}
-//QMap gSummaryChart::dayindex;
-//QList gSummaryChart::daylist;
-
int gSummaryChart::addCalc(ChannelID code, SummaryType type, QColor color)
{
calcitems.append(SummaryCalcItem(code, type, color));
@@ -565,7 +577,8 @@ void gSummaryChart::paint(QPainter &painter, gGraph &graph, const QRegion ®io
totaldays++;
- if (!day) {// || !day->hasMachine(m_machtype)) {
+ if (!day)
+ {
// lasty1 = rect.bottom();
lastx1 += barw;
it++;
@@ -675,9 +688,13 @@ void gSummaryChart::paint(QPainter &painter, gGraph &graph, const QRegion ®io
// This could be turning off graphs prematurely..
if (cache.size() == 0) {
-
m_empty = true;
+ m_emptyPrev = true;
graph.graphView()->updateScale();
+ emit summaryChartEmpty(this,m_minx,m_maxx,true);
+ } else if (m_emptyPrev) {
+ m_emptyPrev = false;
+ emit summaryChartEmpty(this,m_minx,m_maxx,false);
}
}
@@ -1019,8 +1036,8 @@ void gSessionTimesChart::paint(QPainter &painter, gGraph &graph, const QRegion &
totaldays++;
-
- if (!day) { // || !day->hasMachine(m_machtype)) {
+ if (!day)
+ {
// lasty1 = rect.bottom();
lastx1 += barw;
nousedays++;
@@ -1091,6 +1108,7 @@ void gSessionTimesChart::paint(QPainter &painter, gGraph &graph, const QRegion &
afterDraw(painter, graph, rect);
}
+
////////////////////////////////////////////////////////////////////////////
/// Total Time in Apnea Chart Stuff
////////////////////////////////////////////////////////////////////////////
diff --git a/oscar/Graphs/gSessionTimesChart.h b/oscar/Graphs/gSessionTimesChart.h
index a82b69ff..053a1a24 100644
--- a/oscar/Graphs/gSessionTimesChart.h
+++ b/oscar/Graphs/gSessionTimesChart.h
@@ -155,8 +155,9 @@ struct SummaryChartSlice {
// QBrush brush;
};
-class gSummaryChart : public Layer
+class gSummaryChart : public QObject , public Layer
{
+ Q_OBJECT;
public:
gSummaryChart(QString label, MachineType machtype);
gSummaryChart(ChannelID code, MachineType machtype);
@@ -171,6 +172,9 @@ public:
//! \brief Returns true if no data was found for this day during SetDay
virtual bool isEmpty() { return m_empty; }
+ //! \brief Allows chart to recalculate empty flag.
+ void reCalculate() {m_empty=false;};
+
virtual void populate(Day *, int idx);
//! \brief Override to setup custom stuff before main loop
@@ -217,6 +221,8 @@ public:
layer->dayindex = dayindex;
layer->daylist = daylist;
}
+signals:
+ void summaryChartEmpty(gSummaryChart*,qint64,qint64,bool);
protected:
//! \brief Key was pressed that effects this layer
@@ -234,6 +240,7 @@ protected:
QString m_label;
MachineType m_machtype;
bool m_empty;
+ bool m_emptyPrev;
int hl_day;
int tz_offset;
float tz_hours;
@@ -261,6 +268,7 @@ protected:
};
+
/*! \class gSessionTimesChart
\brief Displays a summary of session times
*/
diff --git a/oscar/overview.cpp b/oscar/overview.cpp
index e1375378..2b29ed53 100644
--- a/oscar/overview.cpp
+++ b/oscar/overview.cpp
@@ -7,15 +7,30 @@
* License. See the file COPYING in the main directory of the source code
* for more details. */
+#define xDEBUG_FUNCTIONS
+#ifdef DEBUG_FUNCTIONS
+#include
+#define DEBUGQ qDebug()
+#define DEBUGL qDebug()<
#include
-//#include
#include
#include
#include
#include
#include
-//#include
#include "SleepLib/profiles.h"
#include "overview.h"
@@ -30,11 +45,27 @@
#include "mainwindow.h"
extern MainWindow *mainwin;
+
+qint64 convertDateToTimeRtn(const QDate &date,int hours,int min,int sec) {
+ return QDateTime(date).addSecs(((hours*60+min)*60)+sec).toMSecsSinceEpoch();
+}
+qint64 convertDateToStartTime(const QDate &date) {
+ return convertDateToTimeRtn(date,0,10,0);
+}
+qint64 convertDateToEndTime(const QDate &date) {
+ return convertDateToTimeRtn(date,23,0,0);
+}
+QDate convertTimeToDate(qint64 time) {
+ return QDateTime::fromMSecsSinceEpoch(time).date();
+}
+
Overview::Overview(QWidget *parent, gGraphView *shared) :
QWidget(parent),
ui(new Ui::Overview),
m_shared(shared)
{
+ chartsToBeMonitored.clear();
+ chartsEmpty.clear();;
ui->setupUi(this);
// Set Date controls locale to 4 digit years
@@ -67,7 +98,6 @@ Overview::Overview(QWidget *parent, gGraphView *shared) :
// Connect the signals to update which days have CPAP data when the month is changed
connect(ui->dateStart->calendarWidget(), SIGNAL(currentPageChanged(int, int)), this, SLOT(dateStart_currentPageChanged(int, int)));
connect(ui->dateEnd->calendarWidget(), SIGNAL(currentPageChanged(int, int)), this, SLOT(dateEnd_currentPageChanged(int, int)));
-
QVBoxLayout *framelayout = new QVBoxLayout;
ui->graphArea->setLayout(framelayout);
@@ -143,15 +173,18 @@ Overview::Overview(QWidget *parent, gGraphView *shared) :
connect(GraphView, SIGNAL(updateCurrentTime(double)), this, SLOT(on_LineCursorUpdate(double)));
connect(GraphView, SIGNAL(updateRange(double,double)), this, SLOT(on_RangeUpdate(double,double)));
connect(GraphView, SIGNAL(GraphsChanged()), this, SLOT(updateGraphCombo()));
+ connect(GraphView, SIGNAL(XBoundsChanged(qint64 ,qint64)), this, SLOT(on_XBoundsChanged(qint64 ,qint64)));
}
Overview::~Overview()
{
+ disconnect(GraphView, SIGNAL(XBoundsChanged(qint64 ,qint64)), this, SLOT(on_XBoundsChanged(qint64 ,qint64)));
disconnect(GraphView, SIGNAL(GraphsChanged()), this, SLOT(updateGraphCombo()));
disconnect(GraphView, SIGNAL(updateRange(double,double)), this, SLOT(on_RangeUpdate(double,double)));
disconnect(GraphView, SIGNAL(updateCurrentTime(double)), this, SLOT(on_LineCursorUpdate(double)));
disconnect(ui->dateEnd->calendarWidget(), SIGNAL(currentPageChanged(int, int)), this, SLOT(dateEnd_currentPageChanged(int, int)));
disconnect(ui->dateStart->calendarWidget(), SIGNAL(currentPageChanged(int, int)), this, SLOT(dateStart_currentPageChanged(int, int)));
+ disconnectgSummaryCharts() ;
// Save graph orders and pin status, etc...
GraphView->SaveSettings("Overview");//no trans
@@ -166,18 +199,63 @@ void Overview::ResetFont()
dateLabel->setFont(font);
}
+
+void Overview::connectgSummaryCharts()
+{
+ for (auto it = chartsToBeMonitored.begin(); it != chartsToBeMonitored.end(); ++it) {
+ gSummaryChart* sc =it.key();
+ connect(sc, SIGNAL(summaryChartEmpty(gSummaryChart*,qint64,qint64,bool)), this, SLOT(on_summaryChartEmpty(gSummaryChart*,qint64,qint64,bool)));
+ }
+}
+
+void Overview::disconnectgSummaryCharts()
+{
+ for (auto it = chartsToBeMonitored.begin(); it != chartsToBeMonitored.end(); ++it) {
+ gSummaryChart* sc =it.key();
+ disconnect(sc, SIGNAL(summaryChartEmpty(gSummaryChart*,qint64,qint64,bool)), this, SLOT(on_summaryChartEmpty(gSummaryChart*,qint64,qint64,bool)));
+ }
+ chartsToBeMonitored.clear();
+ chartsEmpty.clear();;
+}
+
+void Overview::on_summaryChartEmpty(gSummaryChart*sc,qint64 firstI,qint64 lastI,bool empty)
+{
+
+ auto it = chartsToBeMonitored.find(sc);
+ if (it==chartsToBeMonitored.end()) {
+ return;
+ }
+ gGraph* graph=it.value();
+ if (empty) {
+ // on next range change allow empty flag to be recalculated
+ chartsEmpty.insert(sc,graph);
+ //DEBUGF << graph->name() << "Chart is Empty" << "Range" << convertTimeToDate(firstI) << convertTimeToDate(lastI);
+ } else {
+ // The chart has some entry with data.
+ chartsEmpty.remove(sc);
+ updateGraphCombo();
+ //DEBUGF << graph->name() << "Chart is enabled with range:" << convertTimeToDate(firstI) << "==>" << convertTimeToDate(lastI) ;
+ }
+ Q_UNUSED(firstI);
+ Q_UNUSED(lastI);
+};
+
+
// Create all the graphs for the Overview page
void Overview::CreateAllGraphs() {
-
///////////////////////////////////////////////////////////////////////////////
// Add all the graphs
// Process is to createGraph() to make the graph object, then add a layer
// that provides the contents for that graph.
///////////////////////////////////////////////////////////////////////////////
+ if (chartsToBeMonitored.size()>0) {
+ disconnectgSummaryCharts();
+ }
+ chartsEmpty.clear();;
+ chartsToBeMonitored.clear();;
// Add graphs that are always included
ChannelID ahicode = p_profile->general->calculateRDI() ? CPAP_RDI : CPAP_AHI;
-
if (ahicode == CPAP_RDI) {
AHI = createGraph("AHIBreakdown", STR_TR_RDI, tr("Respiratory\nDisturbance\nIndex"));
} else {
@@ -186,9 +264,11 @@ void Overview::CreateAllGraphs() {
ahi = new gAHIChart();
AHI->AddLayer(ahi);
+ //chartsToBeMonitored.insert(ahi,AHI);
UC = createGraph(STR_GRAPH_Usage, tr("Usage"), tr("Usage\n(hours)"));
UC->AddLayer(uc = new gUsageChart());
+ //chartsToBeMonitored.insert(uc,UC);
STG = createGraph("New Session", tr("Session Times"), tr("Session Times"), YT_Time);
stg = new gSessionTimesChart();
@@ -197,10 +277,12 @@ void Overview::CreateAllGraphs() {
PR = createGraph("Pressure Settings", STR_TR_Pressure, STR_TR_Pressure + "\n(" + STR_UNIT_CMH2O + ")");
pres = new gPressureChart();
PR->AddLayer(pres);
+ //chartsToBeMonitored.insert(pres,PR);
TTIA = createGraph("TTIA", tr("Total Time in Apnea"), tr("Total Time in Apnea\n(Minutes)"));
ttia = new gTTIAChart();
TTIA->AddLayer(ttia);
+ //chartsToBeMonitored.insert(ttia,TTIA);
// Add graphs for all channels that have been marked in Preferences Dialog as wanting a graph
QHash::iterator chit;
@@ -212,43 +294,59 @@ void Overview::CreateAllGraphs() {
ChannelID code = chan->id();
QString name = chan->fullname();
if (name.length() > 16) name = chan->label();
-// qDebug() << "Channel" << name << "type" << chan->type() << "machine type" << chan->machtype();
gGraph *G = createGraph(chan->code(), name, chan->description());
+ gSummaryChart * sc = nullptr;
if ((chan->type() == schema::FLAG) || (chan->type() == schema::MINOR_FLAG)) {
- gSummaryChart * sc = new gSummaryChart(chan->code(), chan->machtype()); // gts was MT_CPAP
+ sc = new gSummaryChart(chan->code(), chan->machtype()); // gts was MT_CPAP
sc->addCalc(code, ST_CPH, schema::channel[code].defaultColor());
G->AddLayer(sc);
+ chartsToBeMonitored.insert(sc,G);
} else if (chan->type() == schema::SPAN) {
- gSummaryChart * sc = new gSummaryChart(chan->code(), MT_CPAP);
+ sc = new gSummaryChart(chan->code(), MT_CPAP);
sc->addCalc(code, ST_SPH, schema::channel[code].defaultColor());
G->AddLayer(sc);
+ chartsToBeMonitored.insert(sc,G);
} else if (chan->type() == schema::WAVEFORM) {
- G->AddLayer(new gSummaryChart(code, chan->machtype()));
+ sc= new gSummaryChart(code, chan->machtype());
+ G->AddLayer(sc);
+ chartsToBeMonitored.insert(sc,G);
} else if (chan->type() == schema::UNKNOWN) {
- gSummaryChart * sc = new gSummaryChart(chan->code(), MT_CPAP);
+ sc = new gSummaryChart(chan->code(), MT_CPAP);
sc->addCalc(code, ST_CPH, schema::channel[code].defaultColor());
G->AddLayer(sc);
+ chartsToBeMonitored.insert(sc,G);
+ }
+ if (sc== nullptr) {
+ //DEBUGF << "Channel" << name << "type" << chan->type() << "machine type" << chan->machtype() << "IGNORED";
+ } else {
+ sc ->reCalculate();
+ //DEBUGF << "Channel" << name << "type" << chan->type() << "machine type" << chan->machtype() << OO(Empty,sc->isEmpty());
}
} // if showInOverview()
} // for chit
-
+ // Note The following don not use gSummaryChart. They use SummaryChart instead. and can not be monitored.
WEIGHT = createGraph(STR_GRAPH_Weight, STR_TR_Weight, STR_TR_Weight, YT_Weight);
weight = new SummaryChart("Weight", GT_LINE);
weight->setMachineType(MT_JOURNAL);
weight->addSlice(Journal_Weight, QColor("black"), ST_SETAVG);
WEIGHT->AddLayer(weight);
+
BMI = createGraph(STR_GRAPH_BMI, STR_TR_BMI, tr("Body\nMass\nIndex"));
bmi = new SummaryChart("BMI", GT_LINE);
bmi->setMachineType(MT_JOURNAL);
bmi->addSlice(Journal_BMI, QColor("black"), ST_SETAVG);
BMI->AddLayer(bmi);
+
ZOMBIE = createGraph(STR_GRAPH_Zombie, STR_TR_Zombie, tr("How you felt\n(0-10)"));
zombie = new SummaryChart("Zombie", GT_LINE);
zombie->setMachineType(MT_JOURNAL);
zombie->addSlice(Journal_ZombieMeter, QColor("black"), ST_SETAVG);
ZOMBIE->AddLayer(zombie);
+
+ connectgSummaryCharts();
}
+
// Recalculates Overview chart info
void Overview::RebuildGraphs(bool reset)
{
@@ -257,14 +355,16 @@ void Overview::RebuildGraphs(bool reset)
GraphView->GetXBounds(minx, maxx);
}
+ minRangeStartDate=p_profile->LastDay(MT_CPAP);
+ maxRangeEndDate=minRangeStartDate.addDays(-1); // force a range change;
+ disconnectgSummaryCharts() ;
GraphView->trashGraphs(true); // Remove all existing graphs
-
CreateAllGraphs();
if (reset) {
GraphView->resetLayout();
GraphView->setDay(nullptr);
- GraphView->SetXBounds(minx, maxx, 0, false);
+ SetXBounds(minx, maxx, 0, false);
GraphView->resetLayout();
updateGraphCombo();
}
@@ -374,35 +474,12 @@ void Overview::updateGraphCombo()
updateCube();
}
-#if 0
-void Overview::ResetGraphs()
-{
- QDate start = ui->dateStart->date();
- QDate end = ui->dateEnd->date();
- GraphView->setDay(nullptr);
- updateCube();
-
- if (start.isValid() && end.isValid()) {
- setRange(start, end);
- }
-}
-
-void Overview::ResetGraph(QString name)
-{
- gGraph *g = GraphView->findGraph(name);
-
- if (!g) { return; }
-
- g->setDay(nullptr);
- GraphView->redraw();
-}
-#endif
-
void Overview::RedrawGraphs()
{
GraphView->redraw();
}
+// Updates calendar format and profile data.
void Overview::UpdateCalendarDay(QDateEdit *dateedit, QDate date)
{
QCalendarWidget *calendar = dateedit->calendarWidget();
@@ -433,6 +510,71 @@ void Overview::UpdateCalendarDay(QDateEdit *dateedit, QDate date)
calendar->setHorizontalHeaderFormat(QCalendarWidget::ShortDayNames);
}
+
+void Overview::SetXBounds(qint64 start, qint64 end, short group , bool refresh )
+{
+ GraphView->SetXBounds( start , end ,group,refresh);
+}
+
+void Overview::on_XBoundsChanged(qint64 start,qint64 end)
+{
+ displayStartDate = convertTimeToDate(start);
+ displayEndDate = convertTimeToDate(end);
+
+ bool largerRange=false;
+ if (displayStartDate>maxRangeEndDate || minRangeStartDate>displayEndDate) {
+ // have non-overlaping ranges
+ // Only occurs when custom mode is switched to/from a latest mode. custom mode to/from last week.
+ // All other displays expand the existing range.
+ // reset all empty flags to not empty
+ if (displayStartDate>maxRangeEndDate) {
+ //DEBUGF << "Two ranges" O(displayStartDate) <<">" << O(maxRangeEndDate);
+ }
+ if (minRangeStartDate>displayEndDate) {
+ //DEBUGF << "Two ranges" O(minRangeStartDate) <<">" << O(displayEndDate);
+ }
+ largerRange=true;
+ chartsEmpty = QHash( chartsToBeMonitored );
+ minRangeStartDate = displayStartDate;
+ maxRangeEndDate = displayEndDate;
+ } else {
+ // new range overlaps with old range
+ if (displayStartDate" <maxRangeEndDate) {
+ //DEBUGF << "End Higher" <maxRangeEndDate) {
+ //DEBUGF << "ERROR" <isEmpty();
+ if (empty) {
+ sc ->reCalculate();
+ GraphView->updateScale();
+ GraphView->redraw();
+ GraphView->timedRedraw(150);
+ }
+ }
+ chartsEmpty.clear();
+ updateGraphCombo();
+ }
+}
+
void Overview::dateStart_currentPageChanged(int year, int month)
{
QDate d(year, month, 1);
@@ -443,6 +585,7 @@ void Overview::dateStart_currentPageChanged(int year, int month)
UpdateCalendarDay(ui->dateStart, d);
}
}
+
void Overview::dateEnd_currentPageChanged(int year, int month)
{
QDate d(year, month, 1);
@@ -459,7 +602,7 @@ void Overview::on_dateEnd_dateChanged(const QDate &date)
{
qint64 d1 = qint64(QDateTime(ui->dateStart->date(), QTime(0, 10, 0)/*, Qt::UTC*/).toTime_t()) * 1000L;
qint64 d2 = qint64(QDateTime(date, QTime(23, 0, 0)/*, Qt::UTC*/).toTime_t()) * 1000L;
- GraphView->SetXBounds(d1, d2);
+ SetXBounds(d1, d2);
ui->dateStart->setMaximumDate(date);
if (customMode) {
p_profile->general->setCustomOverviewRangeEnd(date);
@@ -470,12 +613,11 @@ void Overview::on_dateStart_dateChanged(const QDate &date)
{
qint64 d1 = qint64(QDateTime(date, QTime(0, 10, 0)/*, Qt::UTC*/).toTime_t()) * 1000L;
qint64 d2 = qint64(QDateTime(ui->dateEnd->date(), QTime(23, 0, 0)/*, Qt::UTC*/).toTime_t()) * 1000L;
- GraphView->SetXBounds(d1, d2);
+ SetXBounds(d1, d2);
ui->dateEnd->setMinimumDate(date);
if (customMode) {
p_profile->general->setCustomOverviewRangeStart(date);
}
-
}
// Zoom to 100% button clicked or called back from 100% zoom in popup menu
@@ -483,7 +625,7 @@ void Overview::on_zoomButton_clicked()
{
qint64 d1 = qint64(QDateTime(ui->dateStart->date(), QTime(0, 10, 0)/*, Qt::UTC*/).toTime_t()) * 1000L; // GTS why UTC?
qint64 d2 = qint64(QDateTime(ui->dateEnd->date(), QTime(23, 0, 0)/*, Qt::UTC*/).toTime_t()) * 1000L; // Interesting: start date set to 10 min after midnight, ending at 11 pm
- GraphView->SetXBounds(d1, d2);
+ SetXBounds(d1, d2);
}
void Overview::ResetGraphLayout()
@@ -501,8 +643,14 @@ void Overview::ResetGraphOrder(int type)
// Process new range selection from combo button
void Overview::on_rangeCombo_activated(int index)
{
+ // Block signal so that graphs are not updated for these.
+ ui->dateEnd->blockSignals(true);
+ ui->dateStart->blockSignals(true);
ui->dateStart->setMinimumDate(p_profile->FirstDay()); // first and last dates for ANY machine type
ui->dateEnd->setMaximumDate(p_profile->LastDay());
+ // these signals will be reenabled in setRange.
+ //ui->dateEnd->blockSignals(false);
+ //ui->dateStart->blockSignals(false);
// Exclude Journal in calculating the last day
QDate end = p_profile->LastDay(MT_CPAP);
@@ -592,21 +740,27 @@ void Overview::on_rangeCombo_activated(int index)
delete progress;
// first and last dates for ANY machine type
+ //uiStartDate=start;
+ //uiEndDate=end;
setRange(start, end);
}
// Saves dates in UI, clicks zoom button, and updates combo box
-void Overview::setRange(QDate start, QDate end)
+// 1. Updates the dates in the start / end date boxs
+// 2. optionally also changes display range for graphs.
+void Overview::setRange(QDate& start, QDate& end, bool updateGraphs/*zoom*/)
{
ui->dateEnd->blockSignals(true);
ui->dateStart->blockSignals(true);
+
ui->dateStart->setMaximumDate(end);
ui->dateEnd->setMinimumDate(start);
ui->dateStart->setDate(start);
ui->dateEnd->setDate(end);
+
ui->dateEnd->blockSignals(false);
ui->dateStart->blockSignals(false);
- this->on_zoomButton_clicked(); // Click on zoom-out to 100% button
+ if (updateGraphs) this->on_zoomButton_clicked(); // Click on zoom-out to 100% button
updateGraphCombo();
}
@@ -631,7 +785,7 @@ void Overview::on_graphCombo_activated(int index)
g = GraphView->findGraphTitle(s);
g->setVisible(b);
-}
+ }
ui->graphCombo->setCurrentIndex(0);
updateCube();
setGraphText();
diff --git a/oscar/overview.h b/oscar/overview.h
index ce543905..df85cf29 100644
--- a/oscar/overview.h
+++ b/oscar/overview.h
@@ -65,7 +65,7 @@ class Overview : public QWidget
void RedrawGraphs();
//! \brief Sets the currently selected date range of the overview display
- void setRange(QDate start, QDate end);
+ void setRange(QDate& start, QDate& end,bool updateGraphs=true);
/*! \brief Create an overview graph, adding it to the overview gGraphView object
\param QString name The title of the graph
@@ -78,11 +78,6 @@ class Overview : public QWidget
gSummaryChart * stg, *uc, *ahi, * pres, *lk, *npb, *rr, *mv, *tv, *nll, *sn, *ttia;
- //! \brief List of SummaryCharts shown on the overview page
- QVector OverviewCharts;
-
- //void ResetGraph(QString name);
-
void RebuildGraphs(bool reset = true);
public slots:
@@ -93,6 +88,8 @@ class Overview : public QWidget
private slots:
void updateGraphCombo();
+ void on_XBoundsChanged(qint64 ,qint64);
+ void on_summaryChartEmpty(gSummaryChart*,qint64,qint64,bool);
//! \brief Resets the graph view because the Start date has been changed
void on_dateStart_dateChanged(const QDate &date);
@@ -120,6 +117,7 @@ class Overview : public QWidget
private:
void CreateAllGraphs();
+ void timedUpdateOverview(int ms=0);
Ui::Overview *ui;
gGraphView *GraphView;
@@ -139,6 +137,23 @@ class Overview : public QWidget
Day *day; // dummy in this case
+
+ bool checkRangeChanged(QDate& first, QDate& last);
+ void connectgSummaryCharts() ;
+ void disconnectgSummaryCharts() ;
+ void SetXBounds(qint64 minx, qint64 maxx, short group = 0, bool refresh = true);
+
+ // Start and of dates of the current graph display
+ QDate displayStartDate;
+ QDate displayEndDate;
+
+ // min / max dates of the graph Range
+ QDate minRangeStartDate;
+ QDate maxRangeEndDate;
+
+ QHash chartsToBeMonitored;
+ QHash chartsEmpty;
+
};
#endif // OVERVIEW_H
From 1be14922c010e5da7a9b88992efb3152283b0547 Mon Sep 17 00:00:00 2001
From: ArieKlerk
Date: Sun, 27 Feb 2022 15:18:39 +0100
Subject: [PATCH 10/14] First series in my translation-cleanup. More to come...
---
oscar/aboutdialog.cpp | 2 +-
oscar/daily.cpp | 16 ++++++++--------
oscar/daily.h | 2 +-
oscar/daily.ui | 2 +-
oscar/mainwindow.cpp | 36 ++++++++++++++++++------------------
oscar/mainwindow.h | 6 +++---
oscar/mainwindow.ui | 2 +-
oscar/newprofile.cpp | 2 +-
oscar/overview.cpp | 6 +++---
oscar/oximeterimport.cpp | 6 +++---
oscar/oximeterimport.ui | 10 +++++-----
oscar/preferencesdialog.cpp | 8 ++++----
oscar/preferencesdialog.ui | 34 +++++++++++++++++-----------------
oscar/profileselector.cpp | 2 +-
oscar/statistics.cpp | 22 +++++++++++-----------
oscar/statistics.h | 4 ++--
oscar/welcome.cpp | 12 ++++++------
oscar/welcome.ui | 2 +-
18 files changed, 87 insertions(+), 87 deletions(-)
diff --git a/oscar/aboutdialog.cpp b/oscar/aboutdialog.cpp
index fe93bbae..5ff9fc87 100644
--- a/oscar/aboutdialog.cpp
+++ b/oscar/aboutdialog.cpp
@@ -127,7 +127,7 @@ QString AboutDialog::getRelnotes()
QString text = ""
""
""+tr("Release Notes")+"
"
- ""+tr("OSCAR %1").arg(getVersion())+""
+ ""+QString("OSCAR %1").arg(getVersion())+""
"
";
if (getVersion().IsReleaseVersion() == false) {
text += ""+tr("Important:")+" "
diff --git a/oscar/daily.h b/oscar/daily.h
index 7e8c50b3..315ae0e0 100644
--- a/oscar/daily.h
+++ b/oscar/daily.h
@@ -279,7 +279,7 @@ private:
\brief Create a new journal session for this date, if one doesn't exist.
\param QDate date
- Creates a new journal Machine record if necessary.
+ Creates a new journal device record if necessary.
*/
Session * CreateJournalSession(QDate date);
diff --git a/oscar/daily.ui b/oscar/daily.ui
index f9f978df..6199b948 100644
--- a/oscar/daily.ui
+++ b/oscar/daily.ui
@@ -1047,7 +1047,7 @@ QToolButton:pressed {
- i
+ i
diff --git a/oscar/mainwindow.ui b/oscar/mainwindow.ui
index 2f69f266..144f1010 100644
--- a/oscar/mainwindow.ui
+++ b/oscar/mainwindow.ui
@@ -2492,7 +2492,7 @@ p, li { white-space: pre-wrap; }
diff --git a/oscar/daily.cpp b/oscar/daily.cpp
index 87e8b85f..33b7e309 100644
--- a/oscar/daily.cpp
+++ b/oscar/daily.cpp
@@ -1108,7 +1108,7 @@ QString Daily::getMachineSettings(Day * day) {
Machine * cpap = day->machine(MT_CPAP);
if (cpap && day->hasEnabledSessions(MT_CPAP)) {
html="
";
- html+=QString("%1 |
").arg(tr("Machine Settings"));
+ html+=QString("%1 |
").arg(tr("Device Settings"));
if (day->noSettings(cpap)) {
html+=""+tr("Please Note: All settings shown below are based on assumptions that nothing has changed since previous days.")+" |
\n";
@@ -1117,7 +1117,7 @@ QString Daily::getMachineSettings(Day * day) {
}
/*
} else if ((day->settingExists(CPAP_BrokenSummary))) {
- html+=""+tr("Machine Settings Unavailable")+" |
\n";
+ html+=""+tr("Device Settings Unavailable")+" |
\n";
return html;
}
*/
@@ -1320,7 +1320,7 @@ QString Daily::getStatisticsInfo(Day * day)
.arg(STR_TR_Min)
.arg(midname)
.arg(QString("%1%2").arg(percentile*100,0,'f',0).arg(STR_UNIT_Percentage))
- .arg(ST_max == ST_MAX?STR_TR_Max:tr("99.5%"));
+ .arg(ST_max == ST_MAX?STR_TR_Max:QString("99.5%"));
ChannelID chans[]={
CPAP_Pressure,CPAP_PressureSet,CPAP_EPAP,CPAP_EPAPSet,CPAP_IPAP,CPAP_IPAPSet,CPAP_PS,CPAP_PTB,
@@ -1705,7 +1705,7 @@ void Daily::Load(QDate date)
.arg("#F88017").arg(COLOR_Text.name()).arg(ahiname).arg(schema::channel[ahichan].fullname()).arg(ahi,0,'f',2);
} else {
htmlLeftAHI+=QString("%2 | \n")
- .arg("#F88017").arg(tr("This CPAP machine does NOT record detailed data"));
+ .arg("#F88017").arg(tr("This CPAP device does NOT record detailed data"));
}
htmlLeftAHI+="\n";
htmlLeftAHI+="\n";
@@ -1732,7 +1732,7 @@ void Daily::Load(QDate date)
QString data;
float channelHours = hours;
if (chan.machtype() != MT_CPAP) {
// Use machine type hours (if available) rather than CPAP hours, since
// might have Oximetry (for example) longer or shorter than CPAP
channelHours = day->hours(chan.machtype());
if (channelHours <= 0) {
@@ -1784,9 +1784,9 @@ void Daily::Load(QDate date)
htmlLeftNoHours+=""+tr("Impossibly short session")+" |
";
htmlLeftNoHours+=""+tr("Zero hours??")+" |
\n";
}
- } else { // machine is a brick
- htmlLeftNoHours+=""+tr("BRICK :(")+" |
";
- htmlLeftNoHours+=""+tr("Sorry, this machine only provides compliance data.")+" |
\n";
+ } else { // Device is a brick
+ htmlLeftNoHours+=""+tr("no data :(")+" |
";
+ htmlLeftNoHours+=""+tr("Sorry, this device only provides compliance data.")+" |
\n";
htmlLeftNoHours+=""+tr("Complain to your Equipment Provider!")+" |
\n";
@@ -1732,7 +1732,7 @@ void Daily::Load(QDate date)
float channelHours = hours;
if (chan.machtype() != MT_CPAP) {
- // Use machine type hours (if available) rather than CPAP hours, since
+ // Use device type hours (if available) rather than CPAP hours, since
// might have Oximetry (for example) longer or shorter than CPAP
channelHours = day->hours(chan.machtype());
}
htmlLeftNoHours+=" |
\n";
diff --git a/oscar/mainwindow.cpp b/oscar/mainwindow.cpp
index bec8259a..5314dfcf 100644
--- a/oscar/mainwindow.cpp
+++ b/oscar/mainwindow.cpp
@@ -281,7 +281,7 @@ void MainWindow::closeEvent(QCloseEvent * event)
static bool runonce = false;
if (!runonce) {
if (AppSetting->removeCardReminder()) {
- Notify(QObject::tr("Don't forget to place your datacard back in your CPAP machine"), QObject::tr("OSCAR Reminder"));
+ Notify(QObject::tr("Don't forget to place your datacard back in your CPAP device"), QObject::tr("OSCAR Reminder"));
QThread::msleep(1000);
QApplication::processEvents();
}
@@ -391,7 +391,7 @@ void MainWindow::PopulatePurgeMenu()
addMachineToMenu(mach, ui->menu_Rebuild_CPAP_Data);
}
// Add any imported machine (except the built-in journal) to the purge menu.
machines = p_profile->GetMachines();
for (int i=0; i < machines.size(); ++i) {
Machine *mach = machines.at(i);
@@ -484,13 +484,13 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
QList machines = p_profile->GetMachines(MT_CPAP);
if (machines.isEmpty()) {
- qDebug() << "No machines in profile";
+ qDebug() << "No devices in profile";
} else {
#ifdef LOCK_RESMED_SESSIONS
for (QList::iterator it = machines.begin(); it != machines.end(); ++it) {
QString mclass=(*it)->loaderName();
if (mclass == STR_MACH_ResMed) {
- qDebug() << "ResMed machine found.. locking OSCAR preferences to suit it's summary system";
+ qDebug() << "ResMed device found.. locking OSCAR preferences to suit it's summary system";
// Have to sacrifice these features to get access to summary data.
p_profile->session->setCombineCloseSessions(0);
@@ -743,7 +743,7 @@ int MainWindow::importCPAP(ImportPath import, const QString &message)
} else if (c == 0) {
Notify(tr("Already up to date with CPAP data at\n\n%1").arg(import.path), tr("Up to date"));
} else {
- Notify(tr("Couldn't find any valid Machine Data at\n\n%1").arg(import.path),tr("Import Problem"));
+ Notify(tr("Couldn't find any valid Device Data at\n\n%1").arg(import.path),tr("Import Problem"));
}
disconnect(progdlg, SIGNAL(abortClicked()), import.loader, SLOT(abortImport()));
disconnect(import.loader, SIGNAL(setProgressMax(int)), progdlg, SLOT(setProgressMax(int)));
@@ -797,7 +797,7 @@ void MainWindow::finishCPAPImport()
void MainWindow::importCPAPBackups()
{
// Get BackupPaths for all CPAP machines
QList machlist = p_profile->GetMachines(MT_CPAP);
QList paths;
Q_FOREACH(Machine *m, machlist) {
@@ -959,7 +959,7 @@ QList MainWindow::detectCPAPCards()
}
Q_FOREACH(const QString &path, AutoScannerPaths) {
// Scan through available machine loaders and test if this folder contains valid folder structure
Q_FOREACH(MachineLoader * loader, loaders) {
if (loader->Detect(path)) {
detectedCards.append(ImportPath(path, loader));
@@ -1748,7 +1748,7 @@ void MainWindow::on_actionPurgeCurrentDayAll_triggered()
this->purgeDay(MT_JOURNAL);
}
// Purge data for a given machine type.
// Special handling: MT_JOURNAL == All data. MT_UNKNOWN == All except journal
void MainWindow::purgeDay(MachineType type)
{
@@ -1848,7 +1848,7 @@ void MainWindow::on_actionRebuildCPAP(QAction *action)
if (backups) {
if (QMessageBox::question(this, STR_MessageBox_Question,
- tr("Are you sure you want to rebuild all CPAP data for the following machine:\n\n") +
+ tr("Are you sure you want to rebuild all CPAP data for the following device:\n\n") +
mach->brand() + " " + mach->model() + " " +
mach->modelnumber() + " (" + mach->serial() + ")\n\n" +
tr("Please note, that this could result in loss of data if OSCAR's backups have been disabled."),
@@ -1858,7 +1858,7 @@ void MainWindow::on_actionRebuildCPAP(QAction *action)
} else {
if (QMessageBox::question(this,
STR_MessageBox_Warning,
- ""+STR_MessageBox_Warning+": "+tr("For some reason, OSCAR does not have any backups for the following machine:")+ "
" +
+ ""+STR_MessageBox_Warning+": "+tr("For some reason, OSCAR does not have any backups for the following device:")+ "
" +
""+mach->brand() + " " + mach->model() + " " + mach->modelnumber() + " (" + mach->serial() + ")
"+
""+tr("Provided you have made your own backups for ALL of your CPAP data, you can still complete this operation, but you will have to restore from your backups manually.")+"
" +
""+tr("Are you really sure you want to do this?")+"
",
@@ -1870,14 +1870,14 @@ void MainWindow::on_actionRebuildCPAP(QAction *action)
QString path = mach->getBackupPath();
MachineLoader *loader = lookupLoader(mach);
- purgeMachine(mach); // purge destroys machine record
+ purgeMachine(mach); // purge destroys device record
if (backups) {
importCPAP(ImportPath(path, loader), tr("Please wait, importing from backup folder(s)..."));
} else {
if (QMessageBox::information(this, STR_MessageBox_Warning,
tr("Because there are no internal backups to rebuild from, you will have to restore from your own.")+"\n\n"+
- tr("Would you like to import from your own backups now? (you will have no data visible for this machine until you do)"),
+ tr("Would you like to import from your own backups now? (you will have no data visible for this device until you do)"),
QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes) == QMessageBox::Yes) {
on_action_Import_Data_triggered();
} else {
@@ -1928,14 +1928,14 @@ void MainWindow::on_actionPurgeMachine(QAction *action)
if (backups) {
backupnotice = "" + tr("Note as a precaution, the backup folder will be left in place.") + "
";
} else {
- backupnotice = "" + tr("OSCAR does not have any backups for this machine!") + "
" +
- "" + tr("Unless you have made your own backups for ALL of your data for this machine, "
- "you will lose this machine's data permanently!") + "
";
+ backupnotice = "" + tr("OSCAR does not have any backups for this device!") + "
" +
+ "" + tr("Unless you have made your own backups for ALL of your data for this device, "
+ "you will lose this device's data permanently!") + "
";
}
if (QMessageBox::question(this, STR_MessageBox_Warning,
""+STR_MessageBox_Warning+": " +
- tr("You are about to obliterate OSCAR's machine database for the following machine:
") +
+ tr("You are about to obliterate OSCAR's device database for the following device:") +
"" + machname + "
" +
backupnotice+
""+tr("Are you absolutely sure you want to proceed?")+"
",
@@ -1958,7 +1958,7 @@ void MainWindow::purgeMachine(Machine * mach)
QDir dir;
QString path = mach->getDataPath();
path.chop(1);
- qDebug() << "path to machine" << path;
+ qDebug() << "path to device" << path;
p_profile->DelMachine(mach);
delete mach;
@@ -2496,7 +2496,7 @@ void MainWindow::on_actionPurgeCurrentDaysOximetry_triggered()
delete sess;
}
// We have to update the summary cache for the affected machine(s),
// otherwise OSCAR will still think this day has oximetry data at next launch.
for (auto & mach : machines) {
mach->SaveSummaryCache();
@@ -391,7 +391,7 @@ void MainWindow::PopulatePurgeMenu()
addMachineToMenu(mach, ui->menu_Rebuild_CPAP_Data);
}
- // Add any imported machine (except the built-in journal) to the purge menu.
+ // Add any imported device (except the built-in journal) to the purge menu.
machines = p_profile->GetMachines();
for (int i=0; i < machines.size(); ++i) {
@@ -797,7 +797,7 @@ void MainWindow::finishCPAPImport()
void MainWindow::importCPAPBackups()
{
- // Get BackupPaths for all CPAP machines
+ // Get BackupPaths for all CPAP devices
QList machlist = p_profile->GetMachines(MT_CPAP);
QList paths;
@@ -959,7 +959,7 @@ QList MainWindow::detectCPAPCards()
}
Q_FOREACH(const QString &path, AutoScannerPaths) {
- // Scan through available machine loaders and test if this folder contains valid folder structure
+ // Scan through available device loaders and test if this folder contains valid folder structure
Q_FOREACH(MachineLoader * loader, loaders) {
if (loader->Detect(path)) {
@@ -1748,7 +1748,7 @@ void MainWindow::on_actionPurgeCurrentDayAll_triggered()
this->purgeDay(MT_JOURNAL);
}
-// Purge data for a given machine type.
+// Purge data for a given device type.
// Special handling: MT_JOURNAL == All data. MT_UNKNOWN == All except journal
void MainWindow::purgeDay(MachineType type)
@@ -2496,7 +2496,7 @@ void MainWindow::on_actionPurgeCurrentDaysOximetry_triggered()
delete sess;
}
- // We have to update the summary cache for the affected machine(s),
+ // We have to update the summary cache for the affected device(s),
// otherwise OSCAR will still think this day has oximetry data at next launch.
for (auto & mach : machines) {
diff --git a/oscar/mainwindow.h b/oscar/mainwindow.h
index 14702fac..2393bb76 100644
--- a/oscar/mainwindow.h
+++ b/oscar/mainwindow.h
@@ -41,7 +41,7 @@ class MainWindow;
Open Source CPAP Analysis Reporter (OSCAR) is a program derived from the SleepyHead program written by Mark Watkins.
- SleepyHead was a Cross-Platform Open-Source software for reviewing data from %CPAP machines, which are used in the treatment of Sleep Disorders.
+ SleepyHead was a Cross-Platform Open-Source software for reviewing data from %CPAP devices, which are used in the treatment of Sleep Disorders.
SleepyHead was created by Mark Watkins (JediMark), an Australian software developer.
@@ -60,7 +60,7 @@ class MainWindow;
\section structure Program Structure
OSCAR is written in C++ using Qt Toolkit library, and comprises of 3 main components
\list
- \li The SleepLib Database, a specialized database for working with multiple sources of Sleep machine data.
+ \li The SleepLib Database, a specialized database for working with multiple sources of Sleep device data.
\li A custom designed, high performance and interactive OpenGL Graphing Library.
\li and the main Application user interface.
\endlist
@@ -408,7 +408,7 @@ private:
void PopulatePurgeMenu();
//! \brief Destroy ALL the CPAP data for the selected machine
void purgeMachine(Machine *);
int warnidx;
@@ -408,7 +408,7 @@ private:
void PopulatePurgeMenu();
- //! \brief Destroy ALL the CPAP data for the selected machine
+ //! \brief Destroy ALL the CPAP data for the selected device
void purgeMachine(Machine *);
int warnidx;